@@ -354,6 +354,7 @@ dcl(LANG_IT_IT, 							"Italian (Italy)")
 dcl(LANG_JA_JP, 							"Japanese")
 dcl(LANG_KN_IN,                             "Kannada")
 dcl(LANG_KO_KR, 							"Korean")
+dcl(LANG_KU, 								"Kurdish")
 dcl(LANG_LO_LA,                             "Lao")
 dcl(LANG_LA_IT, 							"Latin (Renaissance)")	// Is _IT the right thing here?
 dcl(LANG_LV_LV, 							"Latvian")
@@ -391,6 +392,7 @@ dcl(LANG_TH_TH, 							"Thai")
 dcl(LANG_TR_TR, 							"Turkish")
 dcl(LANG_UK_UA, 							"Ukrainian")
 dcl(LANG_UR_PK, 							"Urdu")
+dcl(LANG_UZ_UZ, 							"Uzbek")
 dcl(LANG_VI_VN, 							"Vietnamese")
 dcl(LANG_CY_GB, 							"Welsh")
 dcl(LANG_YI,								"Yiddish")
